<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX User Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Адміністрація</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Додати нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Додати обліковий запис користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Введіть пароль для нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>пароль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Повторно введіть пароль для нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>підтвердіть пароль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Ім&apos;я нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Ім&apos;я користувача для входу:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Введіть ім&apos;я нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>ім&apos;я користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Пароль для нового користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Підтвердити пароль користувача:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Пароль користувача:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Видалити обліковий запис користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Вибір користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Виберіть користувача для видалення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Користувач для видалення:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Також видалити домашній каталог користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Видалити домашній каталог користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Перейменувати обліковий запис користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Виберіть користувача для зміни:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Нове ім&apos;я користувача:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Змінити пароль користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>новий пароль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Підтвердити новий пароль:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>підтвердити новий пароль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Новий пароль користувача:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Відновлення конфігурації користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Змінити обліковий запис користувача</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Виберіть користувача для виправлення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Користувач для зміни:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Скинути на типові значення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Конфігурації Mozilla (Iceweasel або Firefox).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Членство в групах</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Змінити налаштування автовходу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Входити автоматично</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Вимагати пароль для входу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Копіювати/синхронізація</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Копіювати між стільницями</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Виберіть стільницю для копіювання</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Обрати лише копіювання файлів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Лише копіювання</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Виберіть стільницю для копіювання</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Копіювати до:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Копіювати з:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Оберіть, щоб скопіювати, а потім видалити відмінності</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Синхронізувати</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Оберіть для копіювання/синхронізації спільних ресурсів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Спільний каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Оберіть, щоб скопіювати/синхронізувати весь домашній каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Увесь домашній каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Оберіть, щоб скопіювати/синхронізувати конфігурацію браузера</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Конфігурації Mozilla (Firefox або Iceweasel).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Виберіть для копіювання/синхронізації документів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Каталог документів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Що копіювати/синхронізувати:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Перебіг</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Стан змін</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Перебіг змін</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Додати/видалити групи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Додати групу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>назвагрупи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Назва групи:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Видалити групу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Членство в групі</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Групи, до яких належить користувач (змініть групи, встановивши/знявши прапорці):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Скасувати зміни та вийти</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Показати довідку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Застосувати всі зміни</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Про цю програму</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Про...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="156"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="689"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="864"/>
        <location filename="../mainwindow.cpp" line="965"/>
        <location filename="../mainwindow.cpp" line="971"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <source>none</source>
        <translation>нічого</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="870"/>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>browse...</source>
        <translation>огляд...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Конфігурацію користувача буде виправлено. Закрийте всі інші програми. Після завершення вийдіть або перезавантажте систему. Ви впевнені, що хочете виправити її зараз?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>User group membership was restored.</source>
        <translation>Членство в групі користувачів відновлено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Mozilla settings were reset.</source>
        <translation>Налаштування Mozilla скинуто.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Autologin options</source>
        <translation>Опції автоматичного входу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Автоматичний вхід вимкнено для облікового запису «%1».</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Для облікового запису «%1» увімкнено автоматичний вхід.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Ви повинні вказати пункт призначення дії «копіювати». Ви не можете скопіювати на стільницю, на якому ви ввійшли.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Перед копіюванням закрийте всі інші програми. Переконайтеся, що місце призначення копії достатньо велике, щоб умістити файли, які ви копіюєте. Копіювання між стільницями може перезаписати або видалити ваші файли чи налаштування на стільниці призначення. Ви впевнені, що бажаєте продовжити?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Synchronizing desktop...</source>
        <translation>Синхронізація стільниць...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Copying desktop...</source>
        <translation>Копіювання стільниці...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Ім&apos;я користувача має містити принаймні 2 символи. Перш ніж продовжити, виберіть довшу назву.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ім&apos;я користувача не може містити спеціальні символи або пробіли.
Перш ніж продовжити, виберіть інше ім’я.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Це ім&apos;я вже використовується. Введіть інше ім&apos;я.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Паролі не збігаються. Будь ласка, спробуйте ще.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Пароль має бути не менше 2 символів. Перш ніж продовжити, введіть довший пароль.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>The user was added ok.</source>
        <translation>Користувача додано успішно.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Failed to add the user.</source>
        <translation>Не вдалося додати користувача.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Password successfully changed.</source>
        <translation>Пароль успішно змінено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Failed to change password.</source>
        <translation>Не вдалося змінити пароль.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Цю дію неможливо відмінити. Ви впевнені, що бажаєте видалити користувача %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>Користувача видалено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Failed to delete the user.</source>
        <translation>Не вдалося видалити користувача.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Назва групи має містити принаймні 2 символи. Перш ніж продовжити, виберіть довшу назву.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Назва групи має бути написана малими буквами
не може містити спеціальних символів або пробілів.
Перш ніж продовжити, виберіть іншу назву.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Така назва групи вже існує. Будь ласка, введіть іншу назву</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>The system group was added ok.</source>
        <translation>Системну групу додано успішно.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Failed to add the system group.</source>
        <translation>Не вдалося додати системну групу.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="469"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Цю дію не можна скасувати. Ви впевнені, що бажаєте видалити групу %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Failed to delete the group.</source>
        <translation>Не вдалося видалити групу.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The group has been deleted.</source>
        <translation>Групу видалено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>The changes have been applied.</source>
        <translation>Зміни застосовано.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Failed to apply group changes</source>
        <translation>Не вдалося застосувати зміни групи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>The selected user name is currently in use.</source>
        <translation>Вибране ім&apos;я користувача зараз використовується.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Щоб перейменувати цього користувача, будь ласка, вийдіть із системи та увійдіть знову, використовуючи інший обліковий запис користувача.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ім’я користувача має бути написане малими буквами
не може містити спеціальних символів або пробілів.
Перш ніж продовжити, виберіть інше ім’я.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>На жаль, це ім&apos;я вже існує у вашій системі. Будь ласка, введіть інше ім&apos;я.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Не вдалося перейменувати користувача. Будь ласка, переконайтеся, що користувач не ввійшов у систему, можливо, вам знадобиться перезапустити</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>The user was renamed.</source>
        <translation>Користувача було перейменовано.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Синхронізація стільниці... виконано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Copying desktop...ok</source>
        <translation>Копіювання стільниці... виконано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Синхронізація стільниці...не вдалося</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Copying desktop...failed</source>
        <translation>Копіювання стільниці... не вдалося</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Confirmation</source>
        <translation>Підтвердження</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Процес не виконано. Ви впевнені, що бажаєте вийти з програми?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>About %1</source>
        <translation>Про %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Version: </source>
        <translation>Версія:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>Simple user configuration for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%1 License</source>
        <translation>%1 Ліцензія</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>%1 Help</source>
        <translation>%1 Довідка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Select folder to copy to</source>
        <translation>Виберіть каталог для копіювання</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Ліцензія</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Список змін</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Здається, ви ввійшли як root, вийдіть із системи та увійдіть як звичайний користувач, щоб використовувати цю програму.</translation>
    </message>
</context>
</TS>
